@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -30,7 +30,7 @@ class NotesAgentSettingsDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit NotesAgentSettingsDialog(QWidget *parent = Q_NULLPTR);
+    explicit NotesAgentSettingsDialog(QWidget *parent = nullptr);
     ~NotesAgentSettingsDialog();
 
 private Q_SLOTS:
