@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -49,8 +49,8 @@
 
 NotesManager::NotesManager(QObject *parent)
     : QObject(parent),
-      mListener(Q_NULLPTR),
-      mCheckAlarm(Q_NULLPTR)
+      mListener(nullptr),
+      mCheckAlarm(nullptr)
 {
     mSession = new Akonadi::Session("KNotes Session", this);
     mNoteRecorder = new NoteShared::NotesChangeRecorder(this);
@@ -79,7 +79,7 @@ NotesManager::~NotesManager()
 void NotesManager::clear()
 {
     delete mListener;
-    mListener = Q_NULLPTR;
+    mListener = nullptr;
     if (mCheckAlarm && mCheckAlarm->isActive()) {
         mCheckAlarm->stop();
     }
@@ -87,7 +87,7 @@ void NotesManager::clear()
 
 void NotesManager::slotCollectionsReceived(const Akonadi::Collection::List &collections)
 {
-    Q_FOREACH (const Akonadi::Collection &col, collections) {
+    for (const Akonadi::Collection &col : collections) {
         if (!col.contentMimeTypes().contains(Akonadi::NoteUtils::noteMimeType())) {
             continue;
         }
@@ -100,7 +100,7 @@ void NotesManager::slotCollectionsReceived(const Akonadi::Collection::List &coll
         job->fetchScope().fetchFullPayload(true);
         connect(job, &Akonadi::ItemFetchJob::itemsReceived,
                 this, [this](const Akonadi::Item::List &items) {
-                    Q_FOREACH (const Akonadi::Item &item, items) {
+                    for (const Akonadi::Item &item : items) {
                         slotItemAdded(item);
                     }
                 });
@@ -116,9 +116,7 @@ void NotesManager::slotItemAdded(const Akonadi::Item &item)
 
 void NotesManager::slotItemRemoved(const Akonadi::Item &item)
 {
-    if (mListItem.contains(item)) {
-        mListItem.removeAll(item);
-    }
+    mListItem.removeAll(item);
 }
 
 void NotesManager::slotItemChanged(const Akonadi::Item &item, const QSet<QByteArray> &set)
@@ -200,10 +198,10 @@ void NotesManager::slotNewNote(const QString &name, const QString &text)
     KNotification::event(QStringLiteral("receivednotes"),
                          i18n("Note Received"),
                          pixmap,
-                         Q_NULLPTR,
+                         nullptr,
                          KNotification::CloseOnTimeout,
                          QStringLiteral("akonadi_notes_agent"));
-    NoteShared::CreateNewNoteJob *job = new NoteShared::CreateNewNoteJob(this, Q_NULLPTR);
+    NoteShared::CreateNewNoteJob *job = new NoteShared::CreateNewNoteJob(this, nullptr);
     //For the moment it doesn't support richtext.
     job->setRichText(false);
     job->setNote(name, text);
@@ -213,7 +211,7 @@ void NotesManager::slotNewNote(const QString &name, const QString &text)
 void NotesManager::updateNetworkListener()
 {
     delete mListener;
-    mListener = Q_NULLPTR;
+    mListener = nullptr;
 
     if (NoteShared::NoteSharedGlobalConfig::receiveNotes()) {
         // create the socket and start listening for connections
