@@ -57,7 +57,7 @@ int main(int argc, char *argv[])
                          QStringLiteral(KNOTES_VERSION),
                          i18n("KDE Notes"),
                          KAboutLicense::GPL,
-                         i18n("Copyright © 1997–2016 KNotes authors"));
+                         i18n("Copyright © 1997–2017 KNotes authors"));
     knotesAuthors(aboutData);
     app.setAboutData(aboutData);
     QCommandLineParser *cmdArgs = app.cmdArgs();
@@ -84,7 +84,7 @@ void remove_sm_from_client_leader()
     int format, status;
     unsigned long nitems = 0;
     unsigned long extra = 0;
-    unsigned char *data = 0;
+    unsigned char *data = nullptr;
 
     Atom atoms[ 2 ];
     char *atom_names[ 2 ] = { (char *) "WM_CLIENT_LEADER",
