@@ -58,7 +58,7 @@ EXPORT_KONTACT_PLUGIN(KNotesPlugin, knotes)
 KNotesPlugin::KNotesPlugin(KontactInterface::Core *core, const QVariantList &)
     : KontactInterface::Plugin(core, core, "knotes")
 {
-    setComponentName(QStringLiteral("knotes"), QStringLiteral("knotes"));
+    setComponentName(QStringLiteral("knotes"), i18n("KNotes"));
 
     QAction *action =
         new QAction(QIcon::fromTheme(QStringLiteral("knotes")),
@@ -104,7 +104,7 @@ const KAboutData KNotesPlugin::aboutData()
                                       QStringLiteral(KNOTES_VERSION),
                                       xi18nc("@title", "Popup Notes"),
                                       KAboutLicense::GPL_V2,
-                                      xi18nc("@info:credit", "Copyright © 2003–2016 Kontact authors"));
+                                      xi18nc("@info:credit", "Copyright © 2003–2017 Kontact authors"));
 
     aboutData.addAuthor(xi18nc("@info:credit", "Laurent Montel"),
                         xi18nc("@info:credit", "Current Maintainer"),
@@ -190,7 +190,7 @@ void KNotesPlugin::processDropEvent(QDropEvent *event)
                 core(),
                 i18nc("@info", "Dropping multiple mails is not supported."));
         } else {
-            MailSummary mail = mails.first();
+            MailSummary mail = mails.constFirst();
             const QString txt = i18nc("@item", "From: %1\nTo: %2\nSubject: %3",
                                       mail.from(), mail.to(), mail.subject());
             static_cast<KNotesPart *>(part())->newNote(
