@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -101,10 +101,7 @@ void KNotesIconView::addNote(const Akonadi::Item &item)
 
 KNotesIconViewItem *KNotesIconView::iconView(Akonadi::Item::Id id) const
 {
-    if (mNoteList.contains(id)) {
-        return mNoteList.value(id);
-    }
-    return Q_NULLPTR;
+    return mNoteList.value(id);
 }
 
 QHash<Akonadi::Item::Id, KNotesIconViewItem *> KNotesIconView::noteList() const
@@ -135,7 +132,7 @@ KNotesIconViewItem::~KNotesIconViewItem()
 void KNotesIconViewItem::prepare()
 {
     const KMime::Message::Ptr noteMessage = mItem.payload<KMime::Message::Ptr>();
-    const KMime::Headers::Subject *const subject = noteMessage ? noteMessage->subject(false) : Q_NULLPTR;
+    const KMime::Headers::Subject *const subject = noteMessage ? noteMessage->subject(false) : nullptr;
     setText(subject ? subject->asUnicodeString() : QString());
 
     if (mItem.hasAttribute<NoteShared::NoteLockAttribute>()) {
@@ -211,7 +208,7 @@ void KNotesIconViewItem::setIconText(const QString &text, bool save)
 QString KNotesIconViewItem::realName() const
 {
     const KMime::Message::Ptr noteMessage = mItem.payload<KMime::Message::Ptr>();
-    const KMime::Headers::Subject *const subject = noteMessage ? noteMessage->subject(false) : Q_NULLPTR;
+    const KMime::Headers::Subject *const subject = noteMessage ? noteMessage->subject(false) : nullptr;
     return subject ? subject->asUnicodeString() : QString();
 }
 
@@ -321,7 +318,7 @@ void KNotesIconViewItem::setChangeItem(const Akonadi::Item &item, const QSet<QBy
     }
     if (set.contains("PLD:RFC822")) {
         const KMime::Message::Ptr noteMessage = item.payload<KMime::Message::Ptr>();
-        const KMime::Headers::Subject *const subject = noteMessage ? noteMessage->subject(false) : Q_NULLPTR;
+        const KMime::Headers::Subject *const subject = noteMessage ? noteMessage->subject(false) : nullptr;
         setIconText(subject ? subject->asUnicodeString() : QString(), false);
     }
     if (set.contains("NoteDisplayAttribute")) {
