@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -25,7 +25,7 @@ class KNotesListWidgetSearchLine : public KListWidgetSearchLine
 {
     Q_OBJECT
 public:
-    explicit KNotesListWidgetSearchLine(QWidget *parent = Q_NULLPTR);
+    explicit KNotesListWidgetSearchLine(QWidget *parent = nullptr);
     ~KNotesListWidgetSearchLine();
 
     void updateClickMessage(const QString &shortcutStr);
